@@ -479,26 +479,20 @@ class EmailSend(object):
         pass
 
 
-url = "http://elanpy.com:39111/?key=123&method=scrapy"
-
+@ezfuc.retry(2)
 def getIP():
-    res = requests.get(url).json()
-    return res
-
-def addWhite(res):
-    ip_url = "http://httpbin.org/ip"
-    ip_res = requests.get(ip_url).json()["origin"]
-    whiteList = requests.post(url, data={"secret":res["proxyPass"], "ip":ip_res, "order_id":res["proxyUser"]}).json()
-    if str(whiteList["code"])=="200":
-        return True
-    else:
+    ip_url = "http://ip.42.pl/raw"
+    ip_res = requests.get(ip_url).text
+    res = requests.get(f"http://elanpy.com:39111/?key=123&self_ip={ip_res}").json()
+    if res["code"] ==200:
+        return res
+    elif res["code"] ==300:
+        ezfuc.color_print("添加白名单失败", color="yellow")
         ezfuc.sleep(2)
-        ezfuc.color_print("添加白名单失败")
-        addWhite(res)
+        getIP()
 
-def ezproxy(req, add_white=True):
+
+def ezproxy(req):
     res = getIP()
-    if add_white:
-        addWhite(res)
     req.meta["proxy"] = res["proxy"]
     return req
\ No newline at end of file
